==> v2.1.1.zip: woodpecker/README.md <==
# Woodpecker

<p align="center">
  <a href="https://github.com/woodpecker-ci/woodpecker/">
    <img alt="Woodpecker" src="docs/static/img/logo.svg" width="220"/>
  </a>
</p>
<br/>
<p align="center">
  <a href="https://ci.woodpecker-ci.org/repos/3780" title="Build Status">
    <img src="https://ci.woodpecker-ci.org/api/badges/3780/status.svg">
  </a>
  <a href="https://codecov.io/gh/woodpecker-ci/woodpecker">
    <img src="https://codecov.io/gh/woodpecker-ci/woodpecker/branch/main/graph/badge.svg"/>
  </a>
  <a href="https://translate.woodpecker-ci.org/engage/woodpecker-ci/">
    <img src="https://translate.woodpecker-ci.org/widgets/woodpecker-ci/-/ui/svg-badge.svg" alt="Translation status" />
  </a>
  <a href="https://discord.gg/fcMQqSMXJy" title="Join the Discord chat at https://discord.gg/fcMQqSMXJy">
    <img src="https://img.shields.io/discord/838698813463724034.svg?label=discord">
  </a>
  <a href="https://matrix.to/#/#woodpecker:matrix.org" title="Join the Matrix space at https://matrix.to/#/#woodpecker:matrix.org">
    <img src="https://img.shields.io/matrix/woodpecker:matrix.org?label=matrix">
  </a>
  <a href="https://goreportcard.com/report/go.woodpecker-ci.org/woodpecker/v2" title="Go Report Card">
    <img src="https://goreportcard.com/badge/go.woodpecker-ci.org/woodpecker/v2">
  </a>
  <a href="https://pkg.go.dev/go.woodpecker-ci.org/woodpecker/v2" title="go reference">
    <img src="https://pkg.go.dev/badge/go.woodpecker-ci.org/woodpecker/v2">
  </a>
  <a href="https://github.com/woodpecker-ci/woodpecker/releases/latest" title="GitHub release">
    <img src="https://img.shields.io/github/v/release/woodpecker-ci/woodpecker?sort=semver">
  </a>
  <a href="https://hub.docker.com/r/woodpeckerci/woodpecker-server" title="Docker pulls">
    <img src="https://img.shields.io/docker/pulls/woodpeckerci/woodpecker-server">
  </a>
  <a href="https://opensource.org/licenses/Apache-2.0" title="License: Apache-2.0">
    <img src="https://img.shields.io/badge/License-Apache%202.0-blue.svg">
  </a>
  <a href="https://bestpractices.coreinfrastructure.org/projects/5309">
    <img src="https://bestpractices.coreinfrastructure.org/projects/5309/badge">
  </a>
  <a href="https://results.pre-commit.ci/repo/github/179344069" title="pre-commit.ci">
    <img src="https://results.pre-commit.ci/badge/github/woodpecker-ci/woodpecker/main.svg">
  </a>
</p>
<br/>

Woodpecker is a simple yet powerful CI/CD engine with great extensibility.

![woodpecker](docs/docs/woodpecker.png)

## 🫶 Support

Please consider donating and become a backer. 🙏 [[Become a backer](https://opencollective.com/woodpecker-ci#category-CONTRIBUTE)]

<a href="https://opencollective.com/woodpecker-ci" target="_blank"><img src="https://opencollective.com/woodpecker-ci/backers.svg?width=890"></a>

## 📖 Documentation

<https://woodpecker-ci.org/>

## ✨ Contribute

See [Contributing Guide](CONTRIBUTING.md)

[![Open in Gitpod](https://gitpod.io/button/open-in-gitpod.svg)](https://woodpecker-ci.org/docs/next/development/getting-started#gitpod)

## 📣 Translate

We use an own [Weblate](https://weblate.org/en/) instance at [translate.woodpecker-ci.org](https://translate.woodpecker-ci.org).

<a href="https://translate.woodpecker-ci.org/engage/woodpecker-ci/">
  <img src="https://translate.woodpecker-ci.org/widgets/woodpecker-ci/-/ui/multi-blue.svg" alt="Translation status" />
</a>

## 👋 Who uses Woodpecker?

Woodpecker is used by [itself](https://ci.woodpecker-ci.org/woodpecker/woodpecker-ci/) multiple well-known companies, organizations like [Codeberg](https://codeberg.org), hobbyist and many others.

Leave a [comment](https://github.com/woodpecker-ci/woodpecker/discussions/2149) if you're using it as well.

Also consider using the topic `WoodpeckerCI` in your repository, so others can learn from your config and use the hashtag `#WoodpeckerCI` when talking about the project on social media!

Here are some places where people mention Woodpecker:

- [GitHub](https://github.com/topics/WoodpeckerCI)
- [Codeberg](https://codeberg.org/explore/repos?q=woodpeckerci&topic=1)
- [Twitter](https://twitter.com/search?q=%23WoodpeckerCI&src=typed_query)
- [Fediverse](https://mastodon.social/tags/WoodpeckerCI)

## ✨ Stars over time

[![Stargazers over time](https://starchart.cc/woodpecker-ci/woodpecker.svg)](https://starchart.cc/woodpecker-ci/woodpecker)

## License

Woodpecker is Apache 2.0 licensed with the source files in this repository having a header indicating which license they are under and what copyrights apply.

Files under the `docs/` folder are licensed under Creative Commons Attribution-ShareAlike 4.0 International Public License.

==> v2.2.2.zip: woodpecker/README.md <==
# Woodpecker

<p align="center">
  <a href="https://github.com/woodpecker-ci/woodpecker/">
    <img alt="Woodpecker" src="docs/static/img/logo.svg" width="220"/>
  </a>
</p>
<br/>
<p align="center">
  <a href="https://ci.woodpecker-ci.org/repos/3780" title="Build Status">
    <img src="https://ci.woodpecker-ci.org/api/badges/3780/status.svg" alt="Build Status">
  </a>
  <a href="https://codecov.io/gh/woodpecker-ci/woodpecker">
    <img src="https://codecov.io/gh/woodpecker-ci/woodpecker/branch/main/graph/badge.svg" alt="Code coverage">
  </a>
  <a href="https://translate.woodpecker-ci.org/engage/woodpecker-ci/">
    <img src="https://translate.woodpecker-ci.org/widgets/woodpecker-ci/-/ui/svg-badge.svg" alt="Translation status" />
  </a>
  <a href="https://discord.gg/fcMQqSMXJy" title="Join the Discord chat at https://discord.gg/fcMQqSMXJy">
    <img src="https://img.shields.io/discord/838698813463724034.svg?label=discord" alt="Discord chat">
  </a>
  <a href="https://matrix.to/#/#woodpecker:matrix.org" title="Join the Matrix space at https://matrix.to/#/#woodpecker:matrix.org">
    <img src="https://img.shields.io/matrix/woodpecker:matrix.org?label=matrix" alt="Matrix space">
  </a>
  <a href="https://goreportcard.com/report/go.woodpecker-ci.org/woodpecker/v2" title="Go Report Card">
    <img src="https://goreportcard.com/badge/go.woodpecker-ci.org/woodpecker/v2" alt="Go Report Card">
  </a>
  <a href="https://pkg.go.dev/go.woodpecker-ci.org/woodpecker/v2" title="go reference">
    <img src="https://pkg.go.dev/badge/go.woodpecker-ci.org/woodpecker/v2" alt="go reference">
  </a>
  <a href="https://github.com/woodpecker-ci/woodpecker/releases/latest" title="GitHub release">
    <img src="https://img.shields.io/github/v/release/woodpecker-ci/woodpecker?sort=semver" alt="GitHub release">
  </a>
  <a href="https://hub.docker.com/r/woodpeckerci/woodpecker-server" title="Docker pulls">
    <img src="https://img.shields.io/docker/pulls/woodpeckerci/woodpecker-server" alt="Docker pulls">
  </a>
  <a href="https://opensource.org/licenses/Apache-2.0" title="License: Apache-2.0">
    <img src="https://img.shields.io/badge/License-Apache%202.0-blue.svg" alt="License: Apache-2.0">
  </a>
  <a href="https://bestpractices.coreinfrastructure.org/projects/5309">
    <img src="https://bestpractices.coreinfrastructure.org/projects/5309/badge" alt="openssf best practices">
  </a>
  <a href="https://results.pre-commit.ci/repo/github/179344069" title="pre-commit.ci">
    <img src="https://results.pre-commit.ci/badge/github/woodpecker-ci/woodpecker/main.svg" alt="pre-commit.ci">
  </a>
</p>
<br/>

Woodpecker is a simple yet powerful CI/CD engine with great extensibility.

![woodpecker](docs/docs/woodpecker.png)

## 🫶 Support

Please consider donating and become a backer. 🙏 [[Become a backer](https://opencollective.com/woodpecker-ci#category-CONTRIBUTE)]

<a href="https://opencollective.com/woodpecker-ci" target="_blank"><img src="https://opencollective.com/woodpecker-ci/backers.svg?width=890" alt="Open Collective backers"></a>

## 📖 Documentation

<https://woodpecker-ci.org/>

## ✨ Contribute

See [Contributing Guide](CONTRIBUTING.md)

[![Open in Gitpod](https://gitpod.io/button/open-in-gitpod.svg)](https://woodpecker-ci.org/docs/next/development/getting-started#gitpod)

## 📣 Translate

We use an own [Weblate](https://weblate.org/en/) instance at [translate.woodpecker-ci.org](https://translate.woodpecker-ci.org).

<a href="https://translate.woodpecker-ci.org/engage/woodpecker-ci/">
  <img src="https://translate.woodpecker-ci.org/widgets/woodpecker-ci/-/ui/multi-blue.svg" alt="Translation status" />
</a>

## 👋 Who uses Woodpecker?

Woodpecker is used by [itself](https://ci.woodpecker-ci.org/woodpecker/woodpecker-ci/) multiple well-known companies, organizations like [Codeberg](https://codeberg.org), hobbyist and many others.

Leave a [comment](https://github.com/woodpecker-ci/woodpecker/discussions/2149) if you're using it as well.

Also consider using the topic `WoodpeckerCI` in your repository, so others can learn from your config and use the hashtag `#WoodpeckerCI` when talking about the project on social media!

Here are some places where people mention Woodpecker:

- [GitHub](https://github.com/topics/WoodpeckerCI)
- [Codeberg](https://codeberg.org/explore/repos?q=woodpeckerci&topic=1)
- [Twitter](https://twitter.com/search?q=%23WoodpeckerCI&src=typed_query)
- [Fediverse](https://mastodon.social/tags/WoodpeckerCI)

## ✨ Stars over time

[![Stargazers over time](https://starchart.cc/woodpecker-ci/woodpecker.svg)](https://starchart.cc/woodpecker-ci/woodpecker)

## License

Woodpecker is Apache 2.0 licensed with the source files in this repository having a header indicating which license they are under and what copyrights apply.

Files under the `docs/` folder are licensed under Creative Commons Attribution-ShareAlike 4.0 International Public License.
